==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ga-IE/admin/licenses/message.php <==
<?php

return array(

    'does_not_exist' => 'Níl an ceadúnas ann.',
    'user_does_not_exist' => 'Níl an t-úsáideoir ann.',
    'asset_does_not_exist' 	=> 'Níl an tsócmhainn atá tú ag iarraidh a chomhcheangal leis an gceadúnas seo ann.',
    'owner_doesnt_match_asset' => 'Tá somet faoi úinéireacht an tsócmhainn atá tú ag iarraidh a chomhcheangal leis an gceadúnas seo seachas an duine a roghnaíodh sa sannadh chuig an mionsonraithe.',
    'assoc_users'	 => 'Seiceáiltear an ceadúnas seo faoi láthair d\'úsáideoir agus ní féidir é a scriosadh. Seiceáil an ceadúnas sa chéad uair, agus déan iarracht ansin scriosadh arís.',
    'select_asset_or_person' => 'Ní mór duit sócmhainn nó úsáideoir a roghnú, ach níl an dá cheann.',
    'not_found' => 'License not found',


    'create' => array(
        'error'   => 'Níor cruthaíodh an ceadúnas, déan iarracht arís.',
        'success' => 'Cruthaíodh ceadúnas go rathúil.'
    ),

    'deletefile' => array(
        'error'   => 'Ní scriosadh an comhad. Arís, le d\'thoil.',
        'success' => 'Comhad a scriosadh go rathúil',
    ),

    'upload' => array(
        'error'   => 'Comhad (í) nach bhfuil uaslódáil. Arís, le d\'thoil.',
        'success' => 'Comhad (í) uaslódáil go rathúil.',
        'nofiles' => 'Níor roghnaigh tú comhaid ar bith le híoslódáil, nó tá an comhad a bhfuil tú ag iarraidh uaslódáil ró-mhór',
        'invalidfiles' => 'Tá ceann amháin nó níos mó de do chuid comhad ró-mhór nó is comhad í nach bhfuil ceadaithe. Is iad píopaí comhaid a cheadaítear png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar, rtf, xml, and lic.',
    ),

    'update' => array(
        'error'   => 'Níor nuashonraíodh an ceadúnas, déan iarracht arís',
        'success' => 'Tugadh ceadúnas chun dáta go rathúil'
    ),

    'delete' => array(
        'confirm'   => 'An bhfuil tú cinnte gur mian leat an ceadúnas seo a scriosadh?',
        'error'   => 'Bhí ceist ann a scriosadh an ceadúnas. Arís, le d\'thoil.',
        'success' => 'Scriosadh an ceadúnas go rathúil.'
    ),

    'checkout' => array(
        'error'   => 'Bhí ceist ann a sheiceáil amach an ceadúnas. Arís, le d\'thoil.',
        'success' => 'Rinneadh an ceadúnas a sheiceáil go rathúil'
    ),

    'checkin' => array(
        'error'   => 'Bhí ceist ann a sheiceáil sa cheadúnas. Arís, le d\'thoil.',
        'success' => 'Rinneadh an ceadúnas a sheiceáil go rathúil'
    ),

);

==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/ga-IE/admin/licenses/message.php <==
<?php

return array(

    'does_not_exist' => 'License does not exist or you do not have permission to view it.',
    'user_does_not_exist' => 'Níl an t-úsáideoir ann.',
    'asset_does_not_exist' 	=> 'Níl an tsócmhainn atá tú ag iarraidh a chomhcheangal leis an gceadúnas seo ann.',
    'owner_doesnt_match_asset' => 'Tá somet faoi úinéireacht an tsócmhainn atá tú ag iarraidh a chomhcheangal leis an gceadúnas seo seachas an duine a roghnaíodh sa sannadh chuig an mionsonraithe.',
    'assoc_users'	 => 'Seiceáiltear an ceadúnas seo faoi láthair d\'úsáideoir agus ní féidir é a scriosadh. Seiceáil an ceadúnas sa chéad uair, agus déan iarracht ansin scriosadh arís.',
    'select_asset_or_person' => 'Ní mór duit sócmhainn nó úsáideoir a roghnú, ach níl an dá cheann.',
    'not_found' => 'License not found',
    'seats_available' => ':seat_count seats available',


    'create' => array(
        'error'   => 'Níor cruthaíodh an ceadúnas, déan iarracht arís.',
        'success' => 'Cruthaíodh ceadúnas go rathúil.'
    ),

    'deletefile' => array(
        'error'   => 'Ní scriosadh an comhad. Arís, le d\'thoil.',
        'success' => 'Comhad a scriosadh go rathúil',
    ),

    'upload' => array(
        'error'   => 'Comhad (í) nach bhfuil uaslódáil. Arís, le d\'thoil.',
        'success' => 'Comhad (í) uaslódáil go rathúil.',
        'nofiles' => 'Níor roghnaigh tú comhaid ar bith le híoslódáil, nó tá an comhad a bhfuil tú ag iarraidh uaslódáil ró-mhór',
        'invalidfiles' => 'Tá ceann amháin nó níos mó de do chuid comhad ró-mhór nó is comhad í nach bhfuil ceadaithe. Is iad píopaí comhaid a cheadaítear png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar, rtf, xml, and lic.',
    ),

    'update' => array(
        'error'   => 'Níor nuashonraíodh an ceadúnas, déan iarracht arís',
        'success' => 'Tugadh ceadúnas chun dáta go rathúil'
    ),

    'delete' => array(
        'confirm'   => 'An bhfuil tú cinnte gur mian leat an ceadúnas seo a scriosadh?',
        'error'   => 'Bhí ceist ann a scriosadh an ceadúnas. Arís, le d\'thoil.',
        'success' => 'Scriosadh an ceadúnas go rathúil.'
    ),

    'checkout' => array(
        'error'   => 'Bhí ceist ann a sheiceáil amach an ceadúnas. Arís, le d\'thoil.',
        'success' => 'Rinneadh an ceadúnas a sheiceáil go rathúil',
        'not_enough_seats' => 'Not enough license seats available for checkout',
    ),

    'checkin' => array(
        'error'   => 'Bhí ceist ann a sheiceáil sa cheadúnas. Arís, le d\'thoil.',
        'success' => 'Rinneadh an ceadúnas a sheiceáil go rathúil'
    ),

);
